/*
 * DBeaver - Universal Database Manager
 * Copyright (C) 2010-2024 DBeaver Corp and others
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jkiss.dbeaver.model.dashboard.navigator;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.jkiss.code.NotNull;
import org.jkiss.dbeaver.DBException;
import org.jkiss.dbeaver.model.DBIcon;
import org.jkiss.dbeaver.model.DBPImage;
import org.jkiss.dbeaver.model.app.DBPResourceHandler;
import org.jkiss.dbeaver.model.navigator.DBNNode;
import org.jkiss.dbeaver.model.navigator.DBNResource;

/**
 * DBNDashboardFolder
 */
public class DBNDashboardFolder extends DBNResource {
    private static final DBIcon FOLDER_ICON = new DBIcon("platform:/plugin/org.jkiss.dbeaver.model.dashboard/icons/dashboard_folder.png");

    private DBPImage image;

    public DBNDashboardFolder(DBNNode parentNode, IResource resource, DBPResourceHandler handler) throws DBException, CoreException {
        super(parentNode, resource, handler);
    }

    @Override
    protected void dispose(boolean reflect) {
        super.dispose(reflect);
    }

    @NotNull
    @Override
    public DBPImage getResourceNodeIcon() {
        IResource resource = getResource();
        if (resource != null && isRootResource(resource)) {
            if (image == null) {
                image = FOLDER_ICON;
            }
            return image;
        }
        return super.getResourceNodeIcon();
    }

    @Override
    public boolean supportsDrop(DBNNode otherNode) {
        return otherNode instanceof DBNDashboard || super.supportsDrop(otherNode);
    }

}
