/*
 * DBeaver - Universal Database Manager
 * Copyright (C) 2010-2024 DBeaver Corp and others
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jkiss.dbeaver.runtime.ui;

import org.jkiss.code.NotNull;
import org.jkiss.code.Nullable;
import org.jkiss.dbeaver.DBException;
import org.jkiss.dbeaver.model.app.DBPProject;

/**
 * Security UI Service
 */
public interface UIServiceSecurity {

    String askForPassword(@NotNull String title, String message, @Nullable String defPassword, boolean emptyPasswordAllowed);

    /**
     * Ask the password for specific project
     *
     * @return - password
     */
    String askForPassword(
        @NotNull DBPProject project,
        @NotNull String title,
        String message,
        @Nullable String defPassword,
        boolean emptyPasswordAllowed);

    String askForNewPassword(@NotNull String title, @Nullable String defPassword);

    String askForPasswordChange(@NotNull String title, @NotNull String currentPassword);

    boolean validatePassword(DBPProject project, String title, String message, boolean forceEncryption);

    /**
     * Reset project password
     *
     * @param project - current project
     * @throws DBException - thrown exception
     */
    void resetProjectPassword(DBPProject project) throws DBException;
}